@@ -1,7 +1,7 @@
 package Tie::Cycle;
 use strict;
 
-our $VERSION = '1.229';
+our $VERSION = '1.232';
 
 use Carp qw(carp);
 
@@ -68,7 +68,7 @@ sub _item    {
 	$self->[ITEM_COL][ $index ]
 	}
 
-"Tie::Cycle";
+__PACKAGE__;
 
 __END__
 
@@ -147,7 +147,7 @@ brian d foy, C<< <briandfoy@pobox.com> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2000-2025, brian d foy C<< <briandfoy@pobox.com> >>. All rights reserved.
+Copyright © 2000-2026, brian d foy C<< <briandfoy@pobox.com> >>. All rights reserved.
 This software is available under the Artistic License 2.0.
 
 =cut
